@@ -1,6 +1,8 @@
 use strict;
 use warnings;
 
+use Data::Dumper;
+
 $ENV{TESTINGKILLTHEWABBIT} = 1; # make sure we don't load detailed exchg data
 
 {
@@ -14,7 +16,7 @@ $ENV{TESTINGKILLTHEWABBIT} = 1; # make sure we don't load detailed exchg data
     };
   }
 }
- 
+
 note("Common tests for Number::Phone::UK, and also for N::P::StubCountry::MOCK");
 note("The latter is a sanity testto make sure that stubs are built correctly,");
 note("and the comprehensive UK tests make a good torture-test.");
@@ -22,24 +24,24 @@ note("and the comprehensive UK tests make a good torture-test.");
 my $number = Number::Phone->new('+44 142422 0000');
 isa_ok($number, 'Number::Phone::'.(is_mocked_uk() ? 'StubCountry::MOCK' : 'UK'));
 is($number->country(), (is_mocked_uk() ? 'MOCK' : 'UK'), "inherited country() method works");
-ok($number->format() eq '+44 1424 220000', "4+6 number formatted OK");
+is($number->format(), '+44 1424 220000', "4+6 number formatted OK");
 skip_if_mocked("libphonenumber doesn't do areacode/subscriber", 2, sub {
   is($number->areacode(), '1424', "... right area code");
   is($number->subscriber(), '220000', "... right subscriber");
 });
 
 $number = Number::Phone->new('+44 115822 0000');
-ok($number->format() eq '+44 115 822 0000', "3+7 number formatted OK");
+is($number->format(), '+44 115 822 0000', "3+7 number formatted OK");
 skip_if_mocked("libphonenumber doesn't do areacode/subscriber", 2, sub {
   is($number->areacode(), '115', "... right area code");
   is($number->subscriber(), '8220000', "... right subscriber");
 });
 
 $number = Number::Phone->new('+442 0 8771 2924');
-ok($number->format() eq '+44 20 8771 2924', "2+8 number formatted OK");
+is($number->format(), '+44 20 8771 2924', "2+8 number formatted OK");
 skip_if_mocked("libphonenumber doesn't do areacode/subscriber", 2, sub {
-  ok($number->areacode() eq '20', "2+8 number has correct area code");
-  ok($number->subscriber() eq '87712924', "2+8 number has correct subscriber number");
+  is($number->areacode(), '20', "2+8 number has correct area code");
+  is($number->subscriber(), '87712924', "2+8 number has correct subscriber number");
 });
 foreach my $method (qw(is_geographic is_valid), is_mocked_uk() ? () : qw(is_allocated)) {
     ok($number->$method(), "$method works for a London number");
@@ -65,8 +67,8 @@ is_deeply(
 $number = Number::Phone->new('+448450033845');
 is($number->format(), is_mocked_uk() ? '+44 845 003 3845' : '+44 8450033845', "0+10 number formatted OK");
 skip_if_mocked("libphonenumber doesn't do areacode/subscriber", 2, sub {
-  ok($number->areacode() eq '', "0+10 number has no area code");
-  ok($number->subscriber() eq '8450033845', "0+10 number has correct subscriber number");
+  is($number->areacode(), '', "0+10 number has no area code");
+  is($number->subscriber(), '8450033845', "0+10 number has correct subscriber number");
 });
 
 $number = Number::Phone->new('+447979866975');
@@ -99,10 +101,15 @@ skip_if_mocked("libphonenumber doesn't know about location/operators/network-ser
   ok($number->is_network_service(), "network service numbers correctly identified");
 
   $number = Number::Phone->new('+448450033845');
-  ok($number->operator() eq 'Edge Telecom Limited', "operators correctly identified");
+  is($number->operator(), 'Edge Telecom Limited', "operators correctly identified");
 
   $number = Number::Phone->new('+442087712924');
-  ok($number->location()->[0] == 51.38309 && $number->location()->[1] == -0.336079, "geo numbers have correct location");
+  subtest "geo numbers have correct location" => sub {
+      plan tests => 2;
+      my $loc = $number->location();
+      is($loc->[0], 51.38309,  "latitude");
+      is($loc->[1], -0.336079, "longitude");
+  };
   $number = Number::Phone->new('+447979866975');
   ok(!defined($number->location()), "non-geo numbers have no location");
 });
@@ -136,14 +143,19 @@ is_deeply(
     "... and their type looks OK"
 );
 
-$number = Number::Phone->new('+445600123456');
+$number = Number::Phone->new('+445602041914');
 ok($number->is_ipphone(), "VoIP correctly identified");
 
 $number = Number::Phone->new('+443031231234');
 skip_if_mocked("libphonenumber doesn't do operators", 1, sub {
   ok($number->operator() eq 'BT', "03 numbers have right operator");
 });
-is_deeply([sort $number->type()], [sort ((!is_mocked_uk() ? 'is_allocated' : ()), 'is_valid')], "03 numbers have right type");
+is_deeply(
+    [sort $number->type()],
+    [sort ((!is_mocked_uk() ? 'is_allocated' : ()), qw(is_specialrate is_valid))],
+    "03 numbers have right type"
+);
+
 skip_if_mocked("libphonenumber disagrees with me about formatting special rate numbers", 1, sub {
   is($number->format(), '+44 3031231234', "03 numbers are formatted right");
 });
@@ -200,7 +212,7 @@ is($number->format(), '+44 1302 623123', "OFCOM's missing format for 1302 623 is
 
 foreach my $tuple (
   [ 'Number::Phone'     => '+448435235305' ],
-  (is_mocked_uk() ? () : [ 'Number::Phone::UK' =>   '08435235305' ]),
+  (is_mocked_uk() ? () : [ 'Number::Phone::UK' =>   '0843 523 5305' ]),
 ) {
   my($class, $digits) = @{$tuple};
   $number = $class->new($digits);
@@ -212,19 +224,21 @@ foreach my $tuple (
   );
   is_deeply(
       [sort $number->type()],
-      [sort ('is_valid', is_mocked_uk() ? (): qw(is_allocated is_specialrate))],
+      [sort ((!is_mocked_uk() ? 'is_allocated' : ()), qw(is_specialrate is_valid))],
       "... and its type looks OK"
   ) || print Dumper($number->type());
 }
 
 foreach my $tuple (
-  [ 'Number::Phone::UK' => '0844000100'   ],
-  [ 'Number::Phone'     => '+44844000100' ]
+  [ 'Number::Phone::UK' => '0800 903 900'    ],
+  [ 'Number::Phone'     => '+44 800 903 900' ]
 ) {
   my($class, $number) = @{$tuple};
   skip_if_mocked("Stubs aren't intended to be constructed directly", 1, sub {
-    ok(!defined($class->new($number)),
-      "$class->new($number) is undef (too short)");
+    ok(my $obj = $class->new($number),
+      "$class->new($number) 9 digit 08 numbers are A-OK");
+    is($obj->format(), '+44 800903900',
+      "... and formats OK");
   });
 }
 
